posix_fallocate

Function posix_fallocate 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn posix_fallocate( fd: c_int, offset: off_t, len: off_t, ) -> c_int
See https://pubs.opengroup.org/onlinepubs/9799919799/functions/posix_fallocate.html.

Ensures that any required storage for regular file data starting at offset and continuing for len bytes is allocated on the file system storage media.

Upon success, returns 0. Upon failure, returns error number.